@@ -580,15 +580,20 @@ func (m *v2PlatformMigrator) inRegionMachines() []*api.Machine {
 }
 
 func (m *v2PlatformMigrator) validate(ctx context.Context) error {
+	if err := m.validateKnownUnmigratableApps(ctx); err != nil {
+		return err
+	}
+
 	var err error
 	err, extraInfo := m.appConfig.ValidateForMachinesPlatform(ctx)
 	if err != nil {
 		fmt.Println(extraInfo)
 		return fmt.Errorf("failed to validate config for Apps V2 platform: %w", err)
 	}
+
 	err = m.validateScaling(ctx)
 	if err != nil {
-		return nil
+		return err
 	}
 	err = m.validateVolumes(ctx)
 	if err != nil {
@@ -607,6 +612,17 @@ func (m *v2PlatformMigrator) validate(ctx context.Context) error {
 	return nil
 }
 
+func (m *v2PlatformMigrator) validateKnownUnmigratableApps(ctx context.Context) error {
+	// This is as last meassure for very special cases
+	knownUnmigratableApps := []string{
+		"globalconfig-dht", // https://flyio.discourse.team/t/x/2860/6
+	}
+	if slices.Contains(knownUnmigratableApps, m.appCompact.ID) {
+		return fmt.Errorf("Your app uses features incompatible with the V2 platform. Please contact support to discuss how to successfully migrate")
+	}
+	return nil
+}
+
 func (m *v2PlatformMigrator) validateScaling(ctx context.Context) error {
 	// FIXME: for now we fail if there is autoscaling.. remove this once we create any extra machines based on autoscaling config
 	if m.autoscaleConfig.Enabled {
