@@ -27,6 +27,7 @@ type LeasableMachine interface {
 	Start(context.Context) error
 	Destroy(context.Context, bool) error
 	WaitForState(context.Context, string, time.Duration, string) error
+	WaitForSmokeChecksToPass(context.Context, string) error
 	WaitForHealthchecksToPass(context.Context, time.Duration, string) error
 	WaitForEventTypeAfterType(context.Context, string, string, time.Duration) (*api.MachineEvent, error)
 	FormattedMachineId() string
@@ -90,7 +91,7 @@ func (lm *leasableMachine) FormattedMachineId() string {
 		return res
 	}
 	procGroup := lm.Machine().ProcessGroup()
-	if procGroup == "" || lm.Machine().IsFlyAppsReleaseCommand() {
+	if procGroup == "" || lm.Machine().IsFlyAppsReleaseCommand() || lm.Machine().IsFlyAppsConsole() {
 		return res
 	}
 	return fmt.Sprintf("%s [%s]", res, procGroup)
@@ -192,6 +193,62 @@ func (lm *leasableMachine) WaitForState(ctx context.Context, desiredState string
 	}
 }
 
+func (lm *leasableMachine) isConstantlyRestarting(machine *api.Machine) bool {
+	var ev *api.MachineEvent
+
+	for _, mev := range machine.Events {
+		if mev.Type == "exit" {
+			ev = mev
+			break
+		}
+	}
+
+	if ev == nil {
+		return false
+	}
+
+	return !ev.Request.ExitEvent.RequestedStop &&
+		ev.Request.ExitEvent.Restarting &&
+		ev.Request.RestartCount > 1 &&
+		ev.Request.ExitEvent.ExitCode != 0
+}
+
+func (lm *leasableMachine) WaitForSmokeChecksToPass(ctx context.Context, logPrefix string) error {
+	waitCtx, cancel := context.WithTimeout(ctx, 10*time.Second)
+	defer cancel()
+
+	b := &backoff.Backoff{
+		Min:    500 * time.Millisecond,
+		Max:    2 * time.Second,
+		Factor: 2,
+		Jitter: true,
+	}
+
+	fmt.Fprintf(lm.io.ErrOut, "  %s Checking that %s is up and running\n",
+		logPrefix,
+		lm.colorize.Bold(lm.FormattedMachineId()),
+	)
+
+	for {
+		machine, err := lm.flapsClient.Get(waitCtx, lm.Machine().ID)
+		switch {
+		case errors.Is(waitCtx.Err(), context.Canceled):
+			return err
+		case errors.Is(waitCtx.Err(), context.DeadlineExceeded):
+			return nil
+		case err != nil:
+			return fmt.Errorf("error getting machine %s from api: %w", lm.Machine().ID, err)
+		}
+
+		switch {
+		case lm.isConstantlyRestarting(machine):
+			return fmt.Errorf("the app appears to be crashing")
+		default:
+			time.Sleep(b.Duration())
+		}
+	}
+}
+
 func (lm *leasableMachine) WaitForHealthchecksToPass(ctx context.Context, timeout time.Duration, logPrefix string) error {
 	if len(lm.Machine().Checks) == 0 {
 		return nil
