@@ -670,48 +670,41 @@ func TestAppsV2MigrateToV2(t *testing.T) {
 
 // This test takes forever. I'm sorry.
 func TestAppsV2MigrateToV2_Volumes(t *testing.T) {
-	var (
-		err     error
-		f       = testlib.NewTestEnvFromEnv(t)
-		appName = f.CreateRandomAppName()
-	)
-	// No spaces or quotes, this is sent unescaped to bash :x
-	successStr := "myvolumehasloaded"
+	f := testlib.NewTestEnvFromEnv(t)
+	appName := f.CreateRandomAppName()
 
-	f.Fly("launch --org %s --name %s --region %s --internal-port 80 --force-nomad --image nginx", f.OrgSlug(), appName, f.PrimaryRegion())
-	f.Fly("vol create -y --app %s -s 2 --region %s vol_test", appName, f.PrimaryRegion())
-	{
-		toml, err := os.ReadFile("fly.toml")
-		if err != nil {
-			f.Fatalf("failed to read fly.toml: %s\n", err)
-		}
-		tomlStr := string(toml) + "\n[[mounts]]\n  source = \"vol_test\"\n  destination = \"/vol\"\n"
-		if err = os.WriteFile("fly.toml", []byte(tomlStr), 0644); err != nil {
-			f.Fatalf("failed to write fly.toml: %s\n", err)
-		}
-	}
+	f.Fly("apps create %s -o %s --nomad", appName, f.OrgSlug())
+	f.WriteFlyToml(`
+app = "%s"
+primary_region = "%s"
+
+[build]
+  image = "nginx"
+
+[mounts]
+	source = "vol_test"
+	destination = "/vol"
+	`, appName, f.PrimaryRegion())
+
+	f.Fly("vol create -y -s 2 --region %s vol_test", f.PrimaryRegion())
+	f.Fly("deploy --now --force-nomad")
+
+	// Give
+	time.Sleep(2 * time.Second)
+	f.Fly("ssh console -C 'dd if=/dev/random of=/vol/flag.txt bs=1M count=10'")
+	f.Fly("ssh console -C 'sync -f /vol/'")
 
 	assertHasFlag := func() {
-		output := f.Fly("ssh console -q -C 'cat /vol/flag.txt'")
-		output.AssertSuccessfulExit()
-		outStr := string(output.StdOut().Bytes())
-
-		require.Contains(t, outStr, successStr)
+		f.Fly("ssh console -q -C 'test -r /vol/flag.txt'")
 	}
-
-	f.Fly("deploy --now --force-nomad")
-	time.Sleep(2 * time.Second)
-	f.Fly("ssh console -C \"bash -c 'echo %s > /vol/flag.txt && sync'\"", successStr)
-
 	assertHasFlag()
 
-	time.Sleep(9 * time.Second)
+	// time.Sleep(9 * time.Second)
 	f.Fly("migrate-to-v2 --primary-region %s --yes", f.PrimaryRegion())
 	result := f.Fly("status --json")
 
 	var statusMap map[string]any
-	err = json.Unmarshal(result.StdOut().Bytes(), &statusMap)
-	if err != nil {
+	if err := json.Unmarshal(result.StdOut().Bytes(), &statusMap); err != nil {
 		f.Fatalf("failed to parse json: %v [output]: %s\n", err, result.StdOut().String())
 	}
 	platformVersion, _ := statusMap["PlatformVersion"].(string)
@@ -719,3 +712,17 @@ func TestAppsV2MigrateToV2_Volumes(t *testing.T) {
 
 	assertHasFlag()
 }
+
+func TestNoPublicIPDeployMachines(t *testing.T) {
+	var (
+		result *testlib.FlyctlResult
+
+		f       = testlib.NewTestEnvFromEnv(t)
+		appName = f.CreateRandomAppName()
+	)
+
+	f.Fly("launch --org %s --name %s --region %s --now --internal-port 80 --force-machines --image nginx --auto-confirm --no-public-ips", f.OrgSlug(), appName, f.PrimaryRegion())
+	result = f.Fly("ips list --json")
+	// There should be no ips allocated
+	require.Equal(f, "[]\n", result.StdOut().String())
+}
